==> audit_2.4.5.orig.tar.gz: audit-2.4.5/auparse/tcpoptnametab.h <==
/* tcpoptnametab.h --
 * Copyright 2013-14 Red Hat Inc., Durham, North Carolina.
 * All Rights Reserved.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Authors:
 *      Steve Grubb <sgrubb@redhat.com>
 * Location: include/uapi/linux/tcp.h
 */

_S(1, "TCP_NODELAY")
_S(2, "TCP_MAXSEG")
_S(3, "TCP_CORK")
_S(4, "TCP_KEEPIDLE")
_S(5, "TCP_KEEPINTVL")
_S(6, "TCP_KEEPCNT")
_S(7, "TCP_SYNCNT")
_S(8, "TCP_LINGER2")
_S(9, "TCP_DEFER_ACCEPT")
_S(10, "TCP_WINDOW_CLAMP")
_S(11, "TCP_INFO")
_S(12, "TCP_QUICKACK")
_S(13, "TCP_CONGESTION")
_S(14, "TCP_MD5SIG")
_S(15, "TCP_COOKIE_TRANSACTIONS")
_S(16, "TCP_THIN_LINEAR_TIMEOUTS")
_S(17, "TCP_THIN_DUPACK")
_S(18, "TCP_USER_TIMEOUT")
_S(19, "TCP_REPAIR")
_S(20, "TCP_REPAIR_QUEUE")
_S(21, "TCP_QUEUE_SEQ")
_S(22, "TCP_REPAIR_OPTIONS")
_S(23, "TCP_FASTOPEN")
_S(24, "TCP_TIMESTAMP")
_S(25, "TCP_NOTSENT_LOWAT")

==> audit_2.8.2.orig.tar.gz: audit-2.8.2/auparse/tcpoptnametab.h <==
/* tcpoptnametab.h --
 * Copyright 2013-14 Red Hat Inc., Durham, North Carolina.
 * All Rights Reserved.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Authors:
 *      Steve Grubb <sgrubb@redhat.com>
 * Location: include/uapi/linux/tcp.h
 */

_S(1, "TCP_NODELAY")
_S(2, "TCP_MAXSEG")
_S(3, "TCP_CORK")
_S(4, "TCP_KEEPIDLE")
_S(5, "TCP_KEEPINTVL")
_S(6, "TCP_KEEPCNT")
_S(7, "TCP_SYNCNT")
_S(8, "TCP_LINGER2")
_S(9, "TCP_DEFER_ACCEPT")
_S(10, "TCP_WINDOW_CLAMP")
_S(11, "TCP_INFO")
_S(12, "TCP_QUICKACK")
_S(13, "TCP_CONGESTION")
_S(14, "TCP_MD5SIG")
_S(15, "TCP_COOKIE_TRANSACTIONS")
_S(16, "TCP_THIN_LINEAR_TIMEOUTS")
_S(17, "TCP_THIN_DUPACK")
_S(18, "TCP_USER_TIMEOUT")
_S(19, "TCP_REPAIR")
_S(20, "TCP_REPAIR_QUEUE")
_S(21, "TCP_QUEUE_SEQ")
_S(22, "TCP_REPAIR_OPTIONS")
_S(23, "TCP_FASTOPEN")
_S(24, "TCP_TIMESTAMP")
_S(25, "TCP_NOTSENT_LOWAT")
_S(26, "TCP_CC_INFO")
_S(27, "TCP_SAVE_SYN")
_S(28, "TCP_SAVED_SYN")
_S(29, "TCP_REPAIR_WINDOW")
_S(30, "TCP_FASTOPEN_CONNECT")
_S(31, "TCP_ULP")
_S(32, "TCP_MD5SIG_EXT")
